@@ -9,8 +9,8 @@ from importlib.metadata import PackageNotFoundError
 from importlib.metadata import metadata as __load
 from pathlib import Path
 
-logger = logging.getLogger(Path(__file__).parent.name)
-
+pkg = Path(__file__).absolute().parent.name
+logger = logging.getLogger(pkg)
 metadata = None
 try:
     metadata = __load(Path(__file__).absolute().parent.name)
@@ -26,12 +26,10 @@ try:
     __maintainer__ = metadata["maintainer"]
     __contact__ = metadata["maintainer"]
 except PackageNotFoundError:  # pragma: no cover
-    logger.error(
-        f"Could not load package metadata for {Path(__file__).absolute().parent.name}. Is it installed?"
-    )
+    logger.error(f"Could not load package metadata for {pkg}. Is it installed?")
 
 if __name__ == "__main__":  # pragma: no cover
     if metadata is not None:
-        print(f"{metadata['name']} (v{metadata['version']})")
+        print(f"{pkg} (v{metadata['version']})")
     else:
         print("Unknown project info")
